/*eslint new-cap: [2, {"capIsNewExceptions": ["Map"]}]*/
import React, { Component } from 'react';
import JSONTree from 'react-json-tree';
import { Map } from 'immutable';

export default class App extends Component {
  render() {
    const data = {
      array: [1, 2, 3],
      bool: true,
      date: new Date(),
      object: {
        foo: 'bar',
        baz: undefined,
        func: (function User() {})
      },
      symbol: Symbol('value'),
      immutable: Map({ key: 'value' })
    };

    const theme = {
      scheme: 'monokai',
      author: 'wimer hazenberg (http://www.monokai.nl)',
      base00: '#272822',
      base01: '#383830',
      base02: '#49483e',
      base03: '#75715e',
      base04: '#a59f85',
      base05: '#f8f8f2',
      base06: '#f5f4f1',
      base07: '#f9f8f5',
      base08: '#f92672',
      base09: '#fd971f',
      base0A: '#f4bf75',
      base0B: '#a6e22e',
      base0C: '#a1efe4',
      base0D: '#66d9ef',
      base0E: '#ae81ff',
      base0F: '#cc6633'
    };

    const getStyle = (type, expanded) => (expanded ? { textTransform: 'uppercase' } : { textTransform: 'lowercase' });
    const getItemString = (type, data, itemType, itemString) => (<span> // {type}</span>);

    return (
      <div>
        <JSONTree data={ data } />
        <br />
        <h3>Dark Theme</h3>
        <div style={{ backgroundColor: theme.base00 }}>
          <JSONTree data={ data } theme={ theme } />
        </div>
        <br />
        <h3>Style Customization</h3>
        <ul>
          <li>Text changes between uppercase/lowercase based on the expanded state.</li>
          <li>The labels of objects, arrays, and iterables are customized as "// type".</li>
          <li>See code for details.</li>
        </ul>
        <div>
          <JSONTree data={ data } theme={ theme }
                    getArrowStyle={ getStyle }
                    getItemStringStyle={ getStyle }
                    getListStyle={ getStyle }
                    getLabelStyle={ getStyle }
                    getValueStyle={ getStyle }
                    getItemString={ getItemString }/>
        </div>
        <h3>More Fine Grained Rendering</h3>
        <p>Pass <code>labelRenderer</code> or <code>valueRenderer</code>.</p>
        <div>
          <JSONTree data={ data }
                    labelRenderer={raw => <strong>{ raw }</strong>}
                    valueRenderer={raw => <em>{ raw }</em>} />
        </div>
      </div>
    );
  }
}
